import React, { useReducer, useEffect } from 'react';
import axios from 'axios';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var LOADING = 'LOADING';
var SUCCESS = 'SUCCESS';
var ERROR = 'ERROR';

var PUT = "put";
var POST = "post";
var DELETE = "delete";

var baseURL;
var MeyProvider = function MeyProvider(_ref) {
  var children = _ref.children,
      BaseURL = _ref.BaseURL;
  var hyperLink = BaseURL.split(":")[0] + "://";
  var extractedUrl = BaseURL.split(":")[1].split("//")[1];

  if (extractedUrl.includes("/")) {
    var splitURL = extractedUrl.split("");
    baseURL = hyperLink + splitURL.slice(0, splitURL.length - 1).join("");
  } else {
    baseURL = BaseURL;
  }

  return React.createElement(React.Fragment, null, children);
};
var initialfetchState = {
  data: null,
  loading: true,
  error: null
};
var initialMutationState = {
  data: null,
  loading: false,
  error: null
};

var fetchReducer = function fetchReducer(state, action) {
  var _action$payload;

  switch (action.type) {
    case LOADING:
      return _extends({}, state, {
        loading: true
      });

    case SUCCESS:
      return _extends({}, state, {
        loading: false,
        data: (_action$payload = action.payload) === null || _action$payload === void 0 ? void 0 : _action$payload.data,
        error: null
      });

    case ERROR:
      return _extends({}, state, {
        loading: false,
        error: action.error
      });

    default:
      return state;
  }
};

var mutationReducer = function mutationReducer(state, action) {
  var _action$payload2;

  switch (action.type) {
    case LOADING:
      return _extends({}, state, {
        loading: true
      });

    case SUCCESS:
      return _extends({}, state, {
        loading: false,
        data: (_action$payload2 = action.payload) === null || _action$payload2 === void 0 ? void 0 : _action$payload2.data,
        error: null
      });

    case ERROR:
      return _extends({}, state, {
        loading: false,
        error: action.error
      });

    default:
      return state;
  }
};

function useFetch(url, headers) {
  var _useReducer = useReducer(fetchReducer, initialfetchState),
      state = _useReducer[0],
      dispatch = _useReducer[1];

  var URL = baseURL ? baseURL + url : url;
  useEffect(function () {
    axios.get(URL, headers && {
      headers: headers
    }).then(function (resp) {
      dispatch({
        type: SUCCESS,
        payload: resp
      });
    })["catch"](function (err) {
      dispatch({
        type: ERROR,
        error: err.message
      });
    });
  }, []);

  var refetch = function refetch() {
    dispatch({
      type: LOADING
    });
    axios.get(URL, headers && {
      headers: headers
    }).then(function (resp) {
      dispatch({
        type: SUCCESS,
        payload: resp
      });
    })["catch"](function (err) {
      dispatch({
        type: ERROR,
        error: err.message
      });
    });
  };

  return {
    data: state.data,
    loading: state.loading,
    error: state.error,
    refetch: refetch
  };
}

function useMutation(url, requestType, headers) {
  var URL = baseURL ? baseURL + url : url;

  var _useReducer2 = useReducer(mutationReducer, initialMutationState),
      state = _useReducer2[0],
      dispatch = _useReducer2[1];

  var requestHandler = function requestHandler(body) {
    if (typeof body !== "object") {
      console.log("Invalid request body.");
      return;
    }

    dispatch({
      type: LOADING
    });

    if (requestType === POST) {
      axios.post(URL, body, headers && {
        headers: headers
      }).then(function (resp) {
        dispatch({
          type: SUCCESS,
          payload: resp
        });
      })["catch"](function (error) {
        dispatch({
          type: ERROR,
          error: error.message
        });
      });
    }

    if (requestType === PUT) {
      axios.put(URL, body, headers && {
        headers: headers
      }).then(function (resp) {
        dispatch({
          type: SUCCESS,
          payload: resp
        });
      })["catch"](function (error) {
        dispatch({
          type: ERROR,
          error: error.message
        });
      });
    }

    if (requestType === DELETE) {
      axios["delete"](URL, {
        data: body,
        headers: headers && headers
      }).then(function (resp) {
        dispatch({
          type: SUCCESS,
          payload: resp
        });
      })["catch"](function (err) {
        dispatch({
          type: ERROR,
          error: err.message
        });
      });
    }
  };

  return {
    data: state.data,
    loading: state.loading,
    error: state.error,
    handleRequest: requestHandler
  };
}

export { MeyProvider, useFetch, useMutation };
//# sourceMappingURL=index.modern.js.map
